@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,7 +29,9 @@
 #include "code.h"
 #include "util.h"
 #include "groupdef.h"
+#include "pagedef.h"
 #include "section.h"
+#include "htags.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
 #define popen _popen
@@ -176,9 +178,10 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
 { 
   if (d==0) return;
   //printf("Definition::setDocumentation(%s,%s,%d,%d)\n",d,docFile,docLine,stripWhiteSpace);
-  QCString doc;
+  QCString doc = d;
   if (stripWhiteSpace)
   {
+#if 0
     // strip leading empty lines in front of the text, but not the 
     // leading spaces in front of the first line, so list items are 
     // parsed with the correct indent
@@ -200,6 +203,8 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
       doc.at(e)='\0';
       e--;
     }
+#endif
+    doc = stripLeadingAndTrailingEmptyLines(doc);
   }
   else // don't strip whitespace
   {
@@ -216,10 +221,10 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
 void Definition::setBriefDescription(const char *b,const char *briefFile,int briefLine) 
 { 
   if (b==0) return;
-  //printf("Definition::setBriefDescription(%s,%s,%d)\n",b,briefFile,briefLine);
+  //fprintf(stderr,"Definition::setBriefDescription(%s,%s,%d)\n",b,briefFile,briefLine);
   m_brief=QCString(b).stripWhiteSpace();
   int bl=m_brief.length(); 
-  if (bl>0) // add puntuation if needed
+  if (bl>0) // add punctuation if needed
   {
     switch(m_brief.at(bl-1))
     {
@@ -248,7 +253,7 @@ static bool readCodeFragment(const char *fileName,
 {
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString cmd=getFileFilter(fileName)+" \""+fileName+"\"";
+  QCString cmd="\"" + getFileFilter(fileName)+"\" \""+fileName+"\"";
   FILE *f = Config_getBool("FILTER_SOURCE_FILES") ? popen(cmd,"r") : fopen(fileName,"r");
   bool found=FALSE;
   if (f)
@@ -364,7 +369,7 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
     {
       QCString lineStr,anchorStr;
       lineStr.sprintf("%d",m_startBodyLine);
-      anchorStr.sprintf("l%05d",m_startBodyLine);
+      anchorStr.sprintf(Htags::useHtags ? "L%d" : "l%05d",m_startBodyLine);
       ol.newParagraph();
       if (lineMarkerPos<fileMarkerPos) // line marker before file marker
       {
@@ -580,9 +585,13 @@ void Definition::writeSourceRefs(OutputList &ol,const char *scopeName)
 bool Definition::hasDocumentation() const
 { 
   static bool extractAll = Config_getBool("EXTRACT_ALL"); 
-  return !m_doc.isEmpty() ||             // has detailed docs
+  static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
+  bool hasDocs = 
+         !m_doc.isEmpty() ||             // has detailed docs
          !m_brief.isEmpty() ||           // has brief description
-         extractAll;                     // extract everything
+         extractAll ||                   // extract everything
+         (sourceBrowser && m_startBodyLine!=-1 && m_bodyDef); // link to definition
+  return hasDocs;
 }
 
 void Definition::addSourceReferencedBy(MemberDef *md)
@@ -779,13 +788,24 @@ void Definition::writePathFragment(OutputList &ol) const
     else
     {
       ol.writeString("&nbsp;");
-      ol.writeString("/");
+      ol.writeString("&raquo");
       ol.writeString("&nbsp;");
     }
   }
   if (isLinkable())
   {
-    ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_localName);
+    if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const GroupDef*)this)->groupTitle());
+    }
+    else if (definitionType()==Definition::TypePage && !((const PageDef*)this)->title().isEmpty())
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const PageDef*)this)->title());
+    }
+    else
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_localName);
+    }
   }
   else
   {
