@@ -2,7 +2,7 @@
  *
  * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -51,7 +51,7 @@ class Definition
       TypeNamespace, TypePackage, TypePage, TypeDir
     };
     /*! Use this for dynamic inspection of the type of the derived class */
-    virtual DefType definitionType() = 0;
+    virtual DefType definitionType() const = 0;
     
     /*! Create a new definition */
     Definition(
@@ -79,7 +79,7 @@ class Definition
     virtual QCString getOutputFileBase() const = 0;
 
     /*! Returns the name of the source listing of this file. */
-    const QCString getSourceFileBase() const { ASSERT(0); return "NULL"; }
+    virtual QCString getSourceFileBase() const { ASSERT(0); return "NULL"; }
 
     /*! Returns the detailed description of this definition */
     const QCString& documentation() const { return m_doc; }
@@ -195,6 +195,7 @@ class Definition
 
     void writePathFragment(OutputList &ol) const;
     void writeNavigationPath(OutputList &ol) const;
+    virtual void writeQuickMemberLinks(OutputList &,MemberDef *) const {}
 
   protected:
     void setLocalName(const QCString name) { m_localName=name; }
