@@ -3,7 +3,7 @@
  * $Id: dot.cpp,v 1.20 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -566,10 +566,11 @@ static QCString convertLabel(const QCString &l)
     switch(c)
     {
       case '\\': result+="\\\\"; break;
-      case '<': result+="\\<"; break;
-      case '>': result+="\\>"; break;
-      case '|': result+="\\|"; break;
-      default: result+=c; break;
+      case '<':  result+="\\<"; break;
+      case '>':  result+="\\>"; break;
+      case '|':  result+="\\|"; break;
+      case '"':  result+="\\\""; break;
+      default:   result+=c; break;
     }
   }
   return result;
@@ -617,7 +618,8 @@ void DotNode::writeBox(QTextStream &t,
            );
   t << "  Node" << reNumberNode(m_number,reNumber) << " [label=\"";
 
-  if (Config_getBool("UML_LOOK") && (gt==Inheritance || gt==Collaboration))
+  if (m_classDef && Config_getBool("UML_LOOK") && 
+      (gt==Inheritance || gt==Collaboration))
   {
     t << "{" << convertLabel(m_label);
     t << "\\n|";
@@ -711,7 +713,7 @@ void DotNode::writeArrow(QTextStream &t,
     << "\",fontsize=10,style=\"" << edgeStyleMap[ei->m_style] << "\"";
   if (!ei->m_label.isEmpty())
   {
-    t << ",label=\"" << ei->m_label << "\"";
+    t << ",label=\"" << convertLabel(ei->m_label) << "\"";
   }
   if (Config_getBool("UML_LOOK") &&
       arrowStyle[ei->m_color] && 
@@ -3215,7 +3217,7 @@ void DotGroupCollaboration::Edge::write( QTextStream &t, int& )
     for( lli.toFirst(); (link=lli.current()); ++lli)
     {
       if (first) first=FALSE; else t << "\\n"; 
-      t << link->label;
+      t << convertLabel(link->label);
     }
     t << "\"";
 
