@@ -3,7 +3,7 @@
  * $Id: doxygen.h,v 1.39 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -123,7 +123,6 @@ void readConfiguration(int argc, char **argv);
 void parseInput();
 void generateOutput();
 
-//#undef USE_TMP_FILE
-#define USE_TMP_FILE 
+#define NEWMATCH
 
 #endif
