@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -32,7 +32,7 @@
 #include "docparser.h"
 #include "ftvhelp.h"
 #include "searchindex.h"
-//#include "xml.h"
+#include "htags.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
 #define popen _popen
@@ -97,6 +97,15 @@ FileDef::FileDef(const char *p,const char *nm,
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
   acquireFileVersion();
+
+  // members in the detailed part of the documentation
+  docDefineMembers.setInFile(TRUE);
+  docProtoMembers.setInFile(TRUE);
+  docTypedefMembers.setInFile(TRUE);
+  docEnumMembers.setInFile(TRUE);
+  docFuncMembers.setInFile(TRUE);
+  docVarMembers.setInFile(TRUE);
+
 }
 
 /*! destroy the file definition */
@@ -501,6 +510,38 @@ void FileDef::writeDocumentation(OutputList &ol)
     writeDetailedDocumentation(ol);
   }
 
+  writeMemberDocumentation(ol);
+  
+  // write Author section (Man only)
+  ol.disableAllBut(OutputGenerator::Man);
+  ol.startGroupHeader();
+  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
+  ol.endGroupHeader();
+  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
+  ol.enableAll();
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    writeDocAnchorsToTagFile();
+    Doxygen::tagFile << "  </compound>" << endl;
+  }
+
+  endFile(ol);
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    allMemberList.sort();
+    writeMemberPages(ol);
+  }
+}
+
+void FileDef::writeMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+  }
+  
   docDefineMembers.writeDocumentation(ol,name(),this,
                             theTranslator->trDefineDocumentation());
   
@@ -518,22 +559,65 @@ void FileDef::writeDocumentation(OutputList &ol)
   
   docVarMembers.writeDocumentation(ol,name(),this,
                             theTranslator->trVariableDocumentation());
-  
-  // write Author section (Man only)
-  ol.disableAllBut(OutputGenerator::Man);
-  ol.startGroupHeader();
-  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
-  ol.endGroupHeader();
-  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
-  ol.enableAll();
 
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    writeDocAnchorsToTagFile();
-    Doxygen::tagFile << "  </compound>" << endl;
+    ol.enable(OutputGenerator::Html);
+  }
+}
+
+void FileDef::writeMemberPages(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  
+  docDefineMembers.writeDocumentationPage(ol,name(),this);
+  docProtoMembers.writeDocumentationPage(ol,name(),this);
+  docTypedefMembers.writeDocumentationPage(ol,name(),this);
+  docEnumMembers.writeDocumentationPage(ol,name(),this);
+  docFuncMembers.writeDocumentationPage(ol,name(),this);
+  docVarMembers.writeDocumentationPage(ol,name(),this);
+
+  ol.popGeneratorState();
+}
+
+void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
+{
+  static bool createSubDirs=Config_getBool("CREATE_SUBDIRS");
+
+  ol.writeString("      <div class=\"navtab\">\n");
+  ol.writeString("        <table>\n");
+
+  MemberListIterator mli(allMemberList);
+  MemberDef *md;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    if (md->getFileDef()==this && md->getNamespaceDef()==0 && md->isLinkable())
+    {
+      ol.writeString("          <tr><td class=\"navtab\">");
+      if (md->isLinkableInProject())
+      {
+        if (md==currentMd) // selected item => highlight
+        {
+          ol.writeString("<a class=\"qindexHL\" ");
+        }
+        else
+        {
+          ol.writeString("<a class=\"qindex\" ");
+        }
+        ol.writeString("href=\"");
+        if (createSubDirs) ol.writeString("../../");
+        ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+        ol.writeString("\">");
+        ol.writeString(md->localName());
+        ol.writeString("</a>");
+      }
+      ol.writeString("</td></tr>\n");
+    }
   }
 
-  endFile(ol);
+  ol.writeString("        </table>\n");
+  ol.writeString("      </div>\n");
 }
 
 /*! Write a source listing of this file to the output */
@@ -603,6 +687,8 @@ void FileDef::addMembersToMemberGroup()
 void FileDef::insertMember(MemberDef *md)
 {
   //printf("%s:FileDef::insertMember(%s)\n",name().data(),md->name().data());
+  if (allMemberList.find(md)!=-1) return;
+
   allMemberList.append(md); 
   bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
@@ -1148,7 +1234,7 @@ void FileDef::acquireFileVersion()
   if (!vercmd.isEmpty()) 
   {
     msg("Version of %s : ",filepath.data());
-    FILE *f=popen(vercmd+" "+filepath,"r");
+    FILE *f=popen("\""+vercmd+"\" \""+filepath+"\"","r");
     if (!f)
     {
       err("Error: could not execute %s\n",vercmd.data());
@@ -1171,3 +1257,28 @@ void FileDef::acquireFileVersion()
 }
 
 
+QCString FileDef::getSourceFileBase() const
+{ 
+  if (Htags::useHtags)
+  {
+    return Htags::path2URL(filepath);
+  }
+  else
+  {
+    return convertNameToFile(diskname+"-source"); 
+  }
+}
+
+/*! Returns the name of the verbatim copy of this file (if any). */
+QCString FileDef::includeName() const 
+{ 
+  if (Htags::useHtags)
+  {
+    return Htags::path2URL(filepath);
+  }
+  else
+  {
+    return convertNameToFile(diskname+"-source"); 
+  }
+}
+
