@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -218,7 +218,14 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
             md->getOuterScope()->definitionType()==Definition::TypeFile); 
       
       if (srcMd->isFunction() && md->isFunction() && 
+#ifdef NEWMATCH
+          matchArguments2(srcMd->getOuterScope(),srcMd->getFileDef(),srcMd->argumentList(),
+                          md->getOuterScope(),md->getFileDef(),md->argumentList(),
+                          TRUE
+                         ) &&
+#else
           matchArguments(srcMd->argumentList(),md->argumentList()) &&
+#endif
           sameScope
          )
       {
@@ -327,8 +334,8 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
       break;
     default:
       err("GroupDef::insertMembers(): "
-           "member `%s' with class scope `%s' inserted in group scope `%s'!\n",
-           md->name().data(),
+           "member `%s' (typeid=%d) with scope `%s' inserted in group scope `%s'!\n",
+           md->name().data(),md->memberType(),
            md->getClassDef() ? md->getClassDef()->name().data() : "",
            name().data());
   }
@@ -687,6 +694,32 @@ void GroupDef::writeDocumentation(OutputList &ol)
     }
   }
 
+  writeMemberDocumentation(ol);
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    writeDocAnchorsToTagFile();
+    Doxygen::tagFile << "  </compound>" << endl;
+  }
+
+  endFile(ol); 
+  ol.popGeneratorState();
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    allMemberList->sort();
+    writeMemberPages(ol);
+  }
+
+}
+
+void GroupDef::writeMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+  }
+  
   docDefineMembers.writeDocumentation(ol,name(),this,
                              theTranslator->trDefineDocumentation());
   
@@ -705,16 +738,68 @@ void GroupDef::writeDocumentation(OutputList &ol)
   docVarMembers.writeDocumentation(ol,name(),this,
                              theTranslator->trVariableDocumentation());
 
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    writeDocAnchorsToTagFile();
-    Doxygen::tagFile << "  </compound>" << endl;
+    ol.enable(OutputGenerator::Html);
   }
+}
+
+void GroupDef::writeMemberPages(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  
+  docDefineMembers.writeDocumentationPage(ol,name(),this);
+  docProtoMembers.writeDocumentationPage(ol,name(),this);
+  docTypedefMembers.writeDocumentationPage(ol,name(),this);
+  docEnumMembers.writeDocumentationPage(ol,name(),this);
+  docFuncMembers.writeDocumentationPage(ol,name(),this);
+  docVarMembers.writeDocumentationPage(ol,name(),this);
 
-  endFile(ol); 
   ol.popGeneratorState();
 }
 
+void GroupDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
+{
+  static bool createSubDirs=Config_getBool("CREATE_SUBDIRS");
+
+  ol.writeString("      <div class=\"navtab\">\n");
+  ol.writeString("        <table>\n");
+
+  MemberListIterator mli(*allMemberList);
+  MemberDef *md;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    if (md->getGroupDef()==this && md->isLinkable())
+    {
+      ol.writeString("          <tr><td class=\"navtab\">");
+      if (md->isLinkableInProject())
+      {
+        if (md==currentMd) // selected item => highlight
+        {
+          ol.writeString("<a class=\"qindexHL\" ");
+        }
+        else
+        {
+          ol.writeString("<a class=\"qindex\" ");
+        }
+        ol.writeString("href=\"");
+        if (createSubDirs) ol.writeString("../../");
+        ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+        ol.writeString("\">");
+        ol.writeString(md->localName());
+        ol.writeString("</a>");
+      }
+      ol.writeString("</td></tr>\n");
+    }
+  }
+
+  ol.writeString("        </table>\n");
+  ol.writeString("      </div>\n");
+}
+
+
+
 //---- helper functions ------------------------------------------------------
 
 void addClassToGroups(Entry *root,ClassDef *cd)
@@ -803,7 +888,7 @@ void addMemberToGroups(Entry *root,MemberDef *md)
         (gd=Doxygen::groupSDict[g->groupname]) &&
 	g->pri >= pri)
     {
-      if (fgd && g->pri==pri) 
+      if (fgd && gd!=fgd && g->pri==pri) 
       {
          warn(root->fileName.data(), root->startLine,
            "Warning: Member %s found in multiple %s groups! "
