@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -722,7 +722,7 @@ void HtmlDocVisitor::visitPre(DocImage *img)
     }
     m_t << "<div align=\"center\">" << endl;
     m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
-      << baseName << "\"" << htmlAttribsToString(img->attribs()) << ">" << endl;
+      << baseName << "\"" << ">" << endl;
     if (img->hasCaption())
     {
       m_t << "<p><strong>";
@@ -903,13 +903,22 @@ void HtmlDocVisitor::visitPre(DocParamList *pl)
     m_t << "]</tt>&nbsp;";
   }
   m_t << "</td><td valign=\"top\"><em>";
-  QStrListIterator li(pl->parameters());
-  const char *s;
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
   bool first=TRUE;
-  for (li.toFirst();(s=li.current());++li)
+  for (li.toFirst();(param=li.current());++li)
   {
     if (!first) m_t << ","; else first=FALSE;
-    filter(s);
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      visit((DocWord*)param); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      visit((DocLinkedWord*)param); 
+    }
   }
   m_t << "</em>&nbsp;</td><td>";
 }
