@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.56 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -57,7 +57,7 @@ static const char *defaultStyleSheet =
 "       font-size: 120%;\n"
 "}\n"
 "H3 {\n"
-"       font-size: 110%;\n"
+"       font-size: 100%;\n"
 "}\n"
 "CAPTION { font-weight: bold }\n"
 "DIV.qindex {\n"
@@ -78,6 +78,17 @@ static const char *defaultStyleSheet =
 "	padding: 2px;\n"
 "	line-height: 140%;\n"
 "}\n"
+"DIV.navtab {\n"
+"       background-color: #eeeeff;\n"
+"       border: 1px solid #b0b0b0;\n"
+"       text-align: center;\n"
+"       margin: 2px;\n"
+"       margin-right: 15px;\n"
+"       padding: 2px;\n"
+"}\n"
+"TD.navtab {\n"
+"       font-size: 70%;\n"
+"}\n"
 "A.qindex {\n"
 "       text-decoration: none;\n"
 "       font-weight: bold;\n"
@@ -114,7 +125,8 @@ static const char *defaultStyleSheet =
 "A:hover { text-decoration: none; background-color: #f2f2ff }\n"
 "DL.el { margin-left: -1cm }\n"
 ".fragment {\n"
-"       font-family: monospace\n"
+"       font-family: Fixed, monospace;\n"
+"       font-size: 95%;\n"
 "}\n"
 "PRE.fragment {\n"
 "	border: 1px solid #CCCCCC;\n"
@@ -495,34 +507,6 @@ void HtmlGenerator::startFile(const char *name,const char *,
     << versionString << " -->" << endl;
 }
 
-//void HtmlGenerator::startQuickIndexItem(const char *s,const char *l)
-//{
-//  QCString *dest;
-//  if (s) 
-//  {
-//    t << "<a class=\"qindexRef\" ";
-//    t << "doxygen=\"" << s << ":";
-//    if ((dest=Doxygen::tagDestinationDict[s])) t << *dest;
-//    if (strcmp(s,"_cgi")!=0) t << "/"; // small hack to get the cgi binary link right
-//    t << "\" ";
-//  }
-//  else
-//  {
-//    t << "<a class=\"qindex\" ";
-//  }
-//  t << "href=\""; 
-//  if (s)
-//  {
-//    if ((dest=Doxygen::tagDestinationDict[s])) t << *dest;
-//    if (strcmp(s,"_cgi")!=0) t << "/";
-//  }
-//  t << l << "\">";
-//}
-//
-//void HtmlGenerator::endQuickIndexItem()
-//{
-//  t << "</a> &nbsp; ";
-//}
 
 static void writePageFooter(QTextStream &t,const QCString &lastTitle,
                             const QCString relPath)
@@ -615,9 +599,13 @@ void HtmlGenerator::writeStyleInfo(int part)
 }
 
 void HtmlGenerator::startDoxyAnchor(const char *,const char *,
-                                    const char *anchor, const char *name)
+                                    const char *anchor, const char *name,
+                                    const char *args)
 {
-  t << "<a class=\"anchor\" name=\"" << anchor << "\" doxytag=\"" << name << "\"></a>";
+  t << "<a class=\"anchor\" name=\"" << anchor << "\"></a>";
+  t << "<!-- doxytag: member=<" << name << "> ref=<" << anchor << "> args=<";
+  docify(args);
+  t << "> -->";
 }
 
 void HtmlGenerator::endDoxyAnchor(const char *,const char *)
@@ -860,8 +848,10 @@ void HtmlGenerator::codify(const char *str)
                    t << spaces.left(spacesToNextTabStop); 
                    col+=spacesToNextTabStop; 
                    break; 
-        case '\n': t << '\n'; col=0; 
+        case '\n': t << "\n"; col=0; 
                    break;
+        //case '\n': t << "<br>"; col=0; 
+        //           break;
         case '\r': break;
         case '<':  t << "&lt;"; col++; 
                    break;
@@ -869,6 +859,8 @@ void HtmlGenerator::codify(const char *str)
                    break;
         case '&':  t << "&amp;"; col++; 
                    break;
+        //case ' ':  t << "&nbsp;"; col++;
+        //           break;
         case '\\':
                    if (*p=='<')
                      { t << "&lt;"; p++; }
@@ -1380,7 +1372,9 @@ void HtmlGenerator::writeLineNumber(const char *ref,const char *file,
   }
   else
   {
+    startCodeAnchor(lineAnchor);
     codify(lineNumber);
+    endCodeAnchor();
   }
   codify(" ");
 }
