@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -124,8 +124,9 @@ void LatexDocVisitor::visit(DocSymbol *s)
   {
     case DocSymbol::BSlash:  m_t << "$\\backslash$"; break;
     case DocSymbol::At:      m_t << "@"; break;
-    case DocSymbol::Less:    m_t << "$<$"; break;
-    case DocSymbol::Greater: m_t << "$>$"; break;
+    case DocSymbol::Less:    if (m_insidePre) m_t << "<"; else m_t << "$<$"; 
+                             break;
+    case DocSymbol::Greater: if (m_insidePre) m_t << ">"; else m_t << "$>$"; break;
     case DocSymbol::Amp:     m_t << "\\&"; break;
     case DocSymbol::Dollar:  m_t << "\\$"; break;
     case DocSymbol::Hash:    m_t << "\\#"; break;
@@ -909,14 +910,23 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
     m_t << "} ";
   }
   m_t << "{\\em ";
-  QStrListIterator li(pl->parameters());
-  const char *s;
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
   bool first=TRUE;
-  for (li.toFirst();(s=li.current());++li)
+  for (li.toFirst();(param=li.current());++li)
   {
     if (!first) m_t << ","; else first=FALSE;
     m_insideItem=TRUE;
-    filter(s);
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      visit((DocWord*)param); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      visit((DocLinkedWord*)param); 
+    }
     m_insideItem=FALSE;
   }
   m_t << "}]";
