@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -229,9 +229,12 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     "\\usepackage{alltt}\n"
     //"\\usepackage{ae,aecompl,aeguill}\n"
     ;
-  if (Config_getBool("PDF_HYPERLINKS")) 
+  if (Config_getBool("USE_PDFLATEX"))
   {
     t << "\\usepackage{times}" << endl;
+  }
+  if (Config_getBool("PDF_HYPERLINKS")) 
+  {
     t << "\\ifx\\pdfoutput\\undefined" << endl
       << "\\usepackage[ps2pdf," << endl
       << "            pagebackref=true," << endl
@@ -408,12 +411,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2004";
+  //t << "Dimitri van Heesch \\copyright~1997-2005";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2004";
+  //t << "Dimitri van Heesch \\copyright~1997-2005";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -828,14 +831,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2004";
+        //t << " Dimitri van Heesch \\copyright~1997-2005";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2004";
+        //t << " Dimitri van Heesch \\copyright~1997-2005";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -1133,7 +1136,8 @@ void LatexGenerator::endMemberDoc(bool)
 }
 
 void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
-                                     const char *anchor, const char *)
+                                     const char *anchor, const char *,
+                                     const char *)
 {
   if (Config_getBool("PDF_HYPERLINKS"))
   {
