@@ -2,7 +2,7 @@
  *
  * $Id: memberlist.cpp,v 1.35 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -32,6 +32,7 @@ MemberList::MemberList() : QList<MemberDef>()
   m_numDecMembers=-1; // special value indicating that computation is needed
   m_numDocMembers=-1; // special value indicating that computation is needed
   m_inGroup=FALSE;
+  m_inFile=FALSE;
 }
 
 MemberList::~MemberList()
@@ -124,7 +125,7 @@ void MemberList::countDocMembers()
   MemberDef *md;
   for (mli.toFirst();(md=mli.current());++mli)
   {
-    if (md->isDetailedSectionVisible(m_inGroup)) 
+    if (md->isDetailedSectionVisible(m_inGroup,m_inFile)) 
     {
       // do not count enum values, since they do not produce entries of their own
       if (md->memberType()!=MemberDef::EnumValue) m_numDocMembers++;
@@ -243,20 +244,11 @@ void MemberList::writePlainDeclarations(OutputList &ol,
                 if (md->isDetailedSectionLinkable())
                 {
                   ol.disableAllBut(OutputGenerator::Html);
-                  //ol.endEmphasis();
                   ol.docify(" ");
-                  if (md->getGroupDef()!=0 && gd==0) // forward link to group
-                  {
-                    ol.startTextLink(md->getOutputFileBase(),
-                                     md->anchor());
-                  }
-                  else
-                  {
-                    ol.startTextLink(0,md->anchor());
-                  }
+                  ol.startTextLink(md->getOutputFileBase(),
+                                   md->anchor());
                   ol.parseText(theTranslator->trMore());
                   ol.endTextLink();
-                  //ol.startEmphasis();
                   ol.enableAll();
                 }
                 ol.endMemberDescription();
@@ -396,6 +388,47 @@ void MemberList::writeDocumentation(OutputList &ol,
   }
 }
 
+void MemberList::writeDocumentationPage(OutputList &ol,
+                     const char *scopeName, Definition *container)
+{
+  MemberListIterator mli(*this);
+  MemberDef *md;
+  for ( ; (md=mli.current()) ; ++mli)
+  {
+    QCString diskName=md->getOutputFileBase();
+    QCString title=md->qualifiedName();
+    startFile(ol,diskName,md->name(),title);
+    container->writeNavigationPath(ol);
+
+    ol.writeString("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n"
+                   "  <tr>\n"
+                   "   <td valign=\"top\">\n");
+
+    container->writeQuickMemberLinks(ol,md);
+
+    ol.writeString("   </td>\n");
+    ol.writeString("   <td valign=\"top\">\n");
+    
+    md->writeDocumentation(this,ol,scopeName,container,m_inGroup);
+
+    ol.writeString("    </td>\n");
+    ol.writeString("  </tr>\n");
+    ol.writeString("</table>\n");
+    
+    endFile(ol);
+  }
+  if (memberGroupList)
+  {
+    //printf("MemberList::writeDocumentation()  --  member groups\n");
+    MemberGroupListIterator mgli(*memberGroupList);
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      mg->writeDocumentationPage(ol,scopeName,container);
+    }
+  }
+}
+
 void MemberList::addMemberGroup(MemberGroup *mg)
 {
   if (memberGroupList==0)
