@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -38,14 +38,18 @@ class NamespaceDef : public Definition
 {
   public:
     NamespaceDef(const char *defFileName,int defLine,
-                 const char *name,const char *ref=0);
+                 const char *name,const char *ref=0,
+                 const char *refFile=0);
    ~NamespaceDef();
-    DefType definitionType() { return TypeNamespace; }
+    DefType definitionType() const { return TypeNamespace; }
     QCString getOutputFileBase() const;
     void insertUsedFile(const char *fname);
     
     void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
 
     void insertClass(ClassDef *cd);
     void insertNamespace(NamespaceDef *nd);
@@ -162,6 +166,7 @@ class NamespaceSDict : public SDict<NamespaceDef>
                     ((NamespaceDef *)item2)->name()
                    );
     }
+    void writeDeclaration(OutputList &ol,bool localName=FALSE);
 };
 
 
