@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,7 +34,8 @@ class RTFGenerator : public OutputGenerator
     //OutputGenerator *copy();
     //OutputGenerator *clone() { return new RTFGenerator(*this); }
     //void append(const OutputGenerator *o);
-    void enable() { active=TRUE; }
+    void enable() 
+    { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
     void enableIf(OutputType o)  { if (o==RTF) active=TRUE;  }
     void disableIf(OutputType o) { if (o==RTF) active=FALSE; }
@@ -137,7 +138,7 @@ class RTFGenerator : public OutputGenerator
     void lineBreak();
     void startMemberDoc(const char *,const char *,const char *,const char *);
     void endMemberDoc(bool);
-    void startDoxyAnchor(const char *,const char *,const char *,const char *);
+    void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *);
     void startCodeAnchor(const char *) {};
     void endCodeAnchor() {};
