@@ -21,6 +21,17 @@ function readHeader($file)
 
 function computeIndex($word)
 {
+  // Fast string hashing
+  //$lword = strtolower($word);
+  //$l = strlen($lword);
+  //for ($i=0;$i<$l;$i++)
+  //{
+  //  $c = ord($lword{$i});
+  //  $v = (($v & 0xfc00) ^ ($v << 6) ^ $c) & 0xffff;
+  //}
+  //return $v;
+
+  // Simple hashing that allows for substring search
   if (strlen($word)<2) return -1;
   // high char of the index
   $hi = ord($word{0});
@@ -39,7 +50,7 @@ function search($file,$word,&$statsList)
   {
     fseek($file,$index*4+4); // 4 bytes per entry, skip header
     $index = readInt($file);
-    if ($index) // found words matching first two characters
+    if ($index) // found words matching the hash key
     {
       $start=sizeof($statsList);
       $count=$start;
