@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -180,11 +180,11 @@ QCString stripScope(const char *name);
 int iSystem(const char *command,const char *args,bool isBatchFile=FALSE);
 QCString convertToHtml(const char *s);
 QCString convertToXML(const char *s);
-const char * getOverloadDocs();
+QCString getOverloadDocs();
 void addMembersToMemberGroup(MemberList *ml,
                              MemberGroupSDict *memberGroupSDict,
                              Definition *context);
-bool extractClassNameFromType(const QCString &type,int &pos,
+int extractClassNameFromType(const QCString &type,int &pos,
                               QCString &name,QCString &templSpec);
 QCString substituteTemplateArgumentsInString(
        const QCString &name,
@@ -228,6 +228,12 @@ QCString relativePathToRoot(const char *name);
 #define REL_PATH_TO_ROOT "../../"
 void createSubDirs(QDir &d);
 QCString stripPath(const char *s);
+bool containsWord(const QCString &s,const QCString &word);
+bool findAndRemoveWord(QCString &s,const QCString &word);
+QCString stripLeadingAndTrailingEmptyLines(const QCString &s);
+void stringToSearchIndex(const QCString &docUrlBase,const QCString &title,
+                         const QCString &str, bool priority=FALSE,
+                         const QCString &anchor="");
 
 #endif
 
