@@ -3,7 +3,7 @@
  * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -478,6 +478,18 @@ static void writeMemberReference(QTextStream &t,Definition *def,MemberDef *rmd,c
   
 }
 
+static void stripQualifiers(QCString &typeStr)
+{
+  bool done=FALSE;
+  while (!done)
+  {
+    if (typeStr.stripPrefix("static "));
+    else if (typeStr.stripPrefix("virtual "));
+    else if (typeStr.stripPrefix("volatile "));
+    else done=TRUE;
+  }
+}
+
 static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,Definition *def)
 {
 
@@ -493,6 +505,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   // - body code 
   // + template arguments 
   //     (templateArguments(), definitionTemplateParameterLists())
+  // - call graph
   
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
@@ -611,6 +624,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       writeMemberTemplateLists(md,t);
     }
     QCString typeStr = md->typeString(); //replaceAnonymousScopes(md->typeString());
+    stripQualifiers(typeStr);
     t << "        <type>";
     linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),typeStr);
     t << "</type>" << endl;
@@ -791,6 +805,11 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       << md->getDefLine() << "\"";
     if (md->getStartBodyLine()!=-1)
     {
+      FileDef *bodyDef = md->getBodyDef();
+      if (bodyDef)
+      {
+        t << " bodyfile=\"" << bodyDef->absFilePath() << "\"";
+      }
       t << " bodystart=\"" << md->getStartBodyLine() << "\" bodyend=\"" 
         << md->getEndBodyLine() << "\"";
     }
@@ -824,7 +843,19 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
                       MemberList *ml,const char *kind,const char *header=0,
                       const char *documentation=0)
 {
-  if (ml->count()==0) return; // empty list
+  MemberListIterator mli(*ml);
+  MemberDef *md;
+  int count=0;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    // namespace members are also inserted in the file scope, but 
+    // to prevent this duplication in the XML output, we filter those here.
+    if (d->definitionType()!=Definition::TypeFile || md->getNamespaceDef()==0)
+    {
+      count++;
+    }
+  }
+  if (count==0) return; // empty list
 
   t << "      <sectiondef kind=\"" << kind << "\">" << endl;
   if (header)
@@ -837,11 +868,14 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
     writeXMLDocBlock(t,d->docFile(),d->docLine(),d,0,documentation);
     t << "</description>" << endl;
   }
-  MemberListIterator mli(*ml);
-  MemberDef *md;
   for (mli.toFirst();(md=mli.current());++mli)
   {
-    generateXMLForMember(md,ti,t,d);
+    // namespace members are also inserted in the file scope, but 
+    // to prevent this duplication in the XML output, we filter those here.
+    if (d->definitionType()!=Definition::TypeFile || md->getNamespaceDef()==0)
+    {
+      generateXMLForMember(md,ti,t,d);
+    }
   }
   t << "      </sectiondef>" << endl;
 }
@@ -896,7 +930,7 @@ static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
-      if (cd->name().find('@')!=-1) // skip anonymous scopes
+      if (cd->name().find('@')==-1) // skip anonymous scopes
       {
         t << "    <innerclass refid=\"" << cd->getOutputFileBase()
           << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
@@ -913,7 +947,7 @@ static void writeInnerNamespaces(const NamespaceSDict *nl,QTextStream &t)
     NamespaceDef *nd;
     for (nli.toFirst();(nd=nli.current());++nli)
     {
-      if (nd->name().find('@')!=-1) // skip anonymouse scopes
+      if (nd->name().find('@')==-1) // skip anonymouse scopes
       {
         t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
           << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
@@ -1191,6 +1225,11 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     << cd->getDefLine() << "\"";
     if (cd->getStartBodyLine()!=-1)
     {
+      FileDef *bodyDef = cd->getBodyDef();
+      if (bodyDef)
+      {
+        t << " bodyfile=\"" << bodyDef->absFilePath() << "\"";
+      }
       t << " bodystart=\"" << cd->getStartBodyLine() << "\" bodyend=\"" 
         << cd->getEndBodyLine() << "\"";
     }
@@ -1535,7 +1574,8 @@ static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
   t << "\" kind=\"" << kindName << "\">" << endl;
   t << "    <compoundname>" << convertToXML(pd->name()) 
     << "</compoundname>" << endl;
-  SectionInfo *si = Doxygen::sectionDict.find(pd->name());
+
+  SectionInfo *si = Doxygen::sectionDict.find(pageName);
   if (si)
   {
     t << "    <title>" << convertToXML(si->title) << "</title>" << endl;
